@@ -17,7 +17,8 @@
 #' Function to fit thermal reaction norm can be also expressed as : \cr
 #' a 4-parameters [Schoolfield, Sharpe, and Magnuson. 1981] model with DHH, DHA, T12H, and Rho25;
 #' a 6-parameters [Schoolfield, Sharpe, and Magnuson. 1981] model with T12L, DT, DHH, DHL, DHA, and Rho25;
-#' Each of these two first models can be combined as low and high sets of parameters by adding the _L and _H suffix.
+#' Each of these two first models can be combined as low and high sets of parameters by adding the _L suffix to one set.\cr
+#' The Rho25_b control the effect of hygrometry (or Rho25_b_L).\cr
 #' Then you must add also transition_S and transition_P parameters;\cr
 #' It is possible also to add the parameter epsilon and then the model begins SSM + epsilon;\cr
 #' a Weibull function with k (shape), lambda (scale) and theta parameters.\cr
@@ -25,7 +26,8 @@
 #' an asymmetric normal fuction with Peak, Scale, sdH and sdL parameters;\cr
 #' a symmetric trigonometric function with Length, Peak, and Max;\cr
 #' an asymmetric trigonometric function with LengthB, LengthE, Peak, and Max.\cr
-#' 
+#' Dallwitz model can be used using Dallwitz_b1, Dallwitz_b2, Dallwitz_b3, Dallwitz_b4 and Dallwitz_b5 parameters. If Dallwitz_b4 is not included, Dallwitz_b4 = 6 and Dallwitz_b5 = 0.4 will be used instead.\cr
+#' See Dallwitz, M.J., Higgins, J.P., 1992. User’s guide to DEVAR. A computer program for estimating development rate as a function of temperature. CSIRO Aust Div Entomol Rep 2, 1-23.
 #' @examples
 #' \dontrun{
 #' library(embryogrowth)
@@ -200,25 +202,26 @@ for (j in 1:NbTS) temperatures[[j]][1, "Mass"] <- M0
 	}
 
   grR <- getFromNamespace(".gradientRichardson", ns="embryogrowth")
+  nm <- names(parameters)
   
 repeat {
       result <- try(optimx::optimx(par=parameters, 
-                                   fn=getFromNamespace("info.nests", ns="embryogrowth"), 
+                                 fn=getFromNamespace("info.nests", ns="embryogrowth"), 
                                  temperatures=temperatures, 
                                  derivate=derivate, weight=weight,
                                  test=testuse, M0=M0, fixed.parameters=fixed.parameters,
                                  gr=grR, method=method, 
-                                 control=modifyList(control, list(dowarn=FALSE, follow.on=TRUE, kkt=FALSE)), 
+                                 control=modifyList(list(dowarn=FALSE, follow.on=TRUE, kkt=FALSE), control), 
                                  hessian=FALSE), silent=TRUE)
       
 
-    minL <- length(result[[1]])
-    nm <- names(parameters)
+    minL <- nrow(result)
+    
     x <- unlist(result[minL, nm])
     conv <- result[minL, "convcode"]
     value <- result[minL, "value"]
     
-	if (conv == 0) break
+	if (conv != 1) break
 	parameters <- x
 	message("Convergence is not achieved. Optimization continues !")
 	message(dput(parameters))
@@ -226,6 +229,7 @@ repeat {
 }
 
   result_list <- list()
+  result_list$result <- result
   result_list$par <- x
   result_list$value <- value
   result_list$convergence <- conv
@@ -245,28 +249,22 @@ print(result$par)
                     , silent=TRUE)
   
   if (inherits(mathessian, "try-error")) {
+    result$hessian <- NULL
     res <- rep(NA, length(parameters))
+    names(res) <- names(parameters)
   } else {
     rownames(mathessian) <- colnames(mathessian) <- names(x)
-    result$hessian <- mathessian
-    inversemathessian <- try(solve(mathessian), silent=TRUE)
-    if (inherits(inversemathessian, "try-error")) {
-      res <- rep(NA, length(parameters))
-    } else {
-      res <- diag(inversemathessian)
-      res <- ifelse(res<0, NA, sqrt(abs(res)))
-    }
+    rh <- SEfromHessian(mathessian, hessian=TRUE)
+    res <- rh$SE
+    result$hessian <- rh$hessian
   }
   
   if (any(is.na(res))) {
     warning("Problem in Hessian estimation. Confidence interval will not be available.")
-    res <- rep(NA, length(parameters))
+    # res <- rep(NA, length(parameters))
   }
 
-
-names(res) <- names(parameters)
 result$SE <- res 
-
 result$data <- temperatures
 
 # Avant *5. Correction du 17/7/2012
