@@ -18,8 +18,9 @@
 #' @param print Do the results must be printed at screen? TRUE (default) or FALSE
 #' @description Estimate the parameters that best describe the thermal reaction norm for sex ratio when temperature-dependent sex determination occurs.\cr
 #' It can be used also to evaluate the relationship between incubation duration and sex ratio.\cr
-#' The parameter l was defined in Girondot (1999). The TRT is defined from the difference between the two boundary temperatures giving sex ratios of l and 1 \0x2212 l, respectively:\cr
-#' TRTl = abs(S.Kl) where Kl is a constant equal to [2.ln(l/(1-l))].\cr
+#' The parameter l was defined in Girondot (1999). The TRT is defined from the difference between the two boundary temperatures giving sex ratios of \eqn{l} and \eqn{1 - l}, respectively:\cr
+#' \deqn{TRT_{l}=abs\left ( S\: K_{l} \right )}{TRTl = abs( S.Kl )}
+#' where \eqn{K_{l}}{Kl} is a constant equal to \eqn{2\: log\left ( \frac{l}{1-l} \right )}{2 log(l / ( 1 - l))}.\cr
 #' In Girondot (1999), l was 0.05 and then the TRT was defined as being the range of temperatures producing from 5\% to 95\% of each sex.\cr
 #' Models Richards, Double-Richards and Hulin are particularly sensitive for K parameters. If you want estimate 
 #' confidence interval for TRT using these models, it is better to use mcmc.
@@ -29,8 +30,9 @@
 #' @family Functions for temperature-dependent sex determination
 #' @examples
 #' \dontrun{
+#' library(embryogrowth)
 #' CC_AtlanticSW <- subset(DatabaseTSD, RMU=="Atlantic, SW" & 
-#'                           Species=="Caretta caretta" & Sexed!=0)
+#'                           Species=="Caretta caretta" & (!is.na(Sexed) & Sexed!=0))
 #' tsdL <- with (CC_AtlanticSW, tsd(males=Males, females=Females, 
 #'                                  temperatures=Incubation.temperature-Correction.factor, 
 #'                                  equation="logistic", replicate.CI=NULL))
@@ -50,6 +52,8 @@
 #'                DoubleRichards_model=tsdDR, GSD_model=gsd)
 #' compare_AICc(Logistic_Model=tsdL, Hill_model=tsdH, Richards_model=tsdR, 
 #'                DoubleRichards_model=tsdDR, GSD_model=gsd, factor.value = -1)
+#' compare_BIC(Logistic_Model=tsdL, Hill_model=tsdH, Richards_model=tsdR, 
+#'                DoubleRichards_model=tsdDR, GSD_model=gsd, factor.value = -1)
 #' ##############
 #' eo <- subset(DatabaseTSD, Species=="Emys orbicularis", c("Males", "Females", 
 #'                                        "Incubation.temperature"))
@@ -63,7 +67,6 @@
 #'                                  temperatures=Incubation.temperature, 
 #'                                  equation="Richards", replicate.CI=NULL))
 #' ### The Hulin model is a modification of Richards (See Hulin et al. 2009)
-#' ### limit.low.TRT and limit.high.TRT must be setup for Hulin equation
 #' par <- eo_Richards$par
 #' names(par)[which(names(par)=="K")] <- "K2"
 #' par <- c(par, K1=0)
@@ -107,9 +110,10 @@ tsd <- function(df=NULL, males=NULL, females=NULL, N=NULL,
                 equation="logistic", replicate.CI=10000, range.CI=0.95, 
                 print=TRUE) {
   
-  # df=NULL; males=NULL; females=NULL; N=NULL; temperatures=NULL; durations=NULL; l=0.05; parameters.initial=c(P=NA, S=-0.5, K=0, K1=1, K2=0); males.freq=TRUE; fixed.parameters=NULL; equation="logistic"; replicate.CI=1000; range.CI=0.95; print=TRUE
+  # df=NULL; males=NULL; females=NULL; N=NULL; temperatures=NULL; durations=NULL; l=0.05; parameters.initial=c(P=NA, S=-0.5, K=0, K1=1, K2=0); males.freq=TRUE; fixed.parameters=NULL; equation="logistic"; replicate.CI=10000; range.CI=0.95; print=TRUE
   # CC_AtlanticSW <- subset(DatabaseTSD, RMU=="Atlantic, SW" & Species=="Caretta caretta" & Sexed!=0)
   # males=CC_AtlanticSW$Males; females=CC_AtlanticSW$Females; temperatures=CC_AtlanticSW$Incubation.temperature-CC_AtlanticSW$Correction.factor; equation="Richards"
+  
   equation <- tolower(equation)
   
   if (!is.null(df)) {
@@ -200,29 +204,20 @@ tsd <- function(df=NULL, males=NULL, females=NULL, N=NULL,
     
     repeat {
      # result  <- optim(par, embryogrowth:::.tsd_fit, fixed.parameters=fixed.parameters, males=males, N=N, temperatures=temperatures, equation=equation, method="BFGS", hessian=TRUE, control = list(maxit=1000))
-     result  <- optim(par, getFromNamespace(".tsd_fit", ns="embryogrowth"), fixed.parameters=fixed.parameters, males=males, N=N, temperatures=temperatures, equation=equation, method="BFGS", hessian=TRUE, control = list(maxit=1000))
+     result  <- optim(par, getFromNamespace(".tsd_fit", ns="embryogrowth"), 
+           fixed.parameters=fixed.parameters, males=males, N=N, temperatures=temperatures, 
+           equation=equation, method="BFGS", hessian=TRUE, control = list(maxit=1000))
 
-      if (result$convergence==0) break
+      if (result$convergence != 1) break
       par<-result$par
       if (print) print("Convergence is not acheived. Optimization continues !")
     }
 
     par <- c(result$par, fixed.parameters)
     
-      mathessian <- result$hessian
-      
-      inversemathessian <- try(solve(mathessian), silent=TRUE)
-      
-      if (inherits(inversemathessian, "try-error")) {
-        res <- rep(NA, length(par))
-        names(res) <- names(par)
-      } else {
-        res <- diag(inversemathessian)
-        res <- ifelse(res<0, NA, sqrt(abs(res)))
-      }
-    
-    
-    result$SE <- res
+    rh <- SEfromHessian(result$hessian, hessian=TRUE)
+    result$SE <- rh$SE
+    result$hessian <- rh$hessian
     result$AIC <- 2*result$value+2*length(par)
   }
   
@@ -234,7 +229,7 @@ tsd <- function(df=NULL, males=NULL, females=NULL, N=NULL,
 
     class(result) <- "tsd"
    # result <<- result
-    o <- P_TRT(result, temperatures=NULL, l=l, 
+    o <- P_TRT(x=result, temperatures=NULL, l=l, 
                replicate.CI = replicate.CI, probs = c((1-range.CI)/2, 0.5, 1-(1-range.CI)/2))
     
     result$P_TRT <- o$P_TRT_quantiles
